data <- read.csv("data.csv")

library(Design)
attach(data)

# final

lrm.out.final <- lrm(fall ~ duration + minister.num 
 + senator 
 + gov.rate.rep + pass + partisan2
 + experienceArmy + experienceNavy + as.integer(bukan>0) # July 8, 2011, the order of variables are corrected
 + agriculture,
 data=data,y=T,x=T)
lrm.out.final.rob <- robcov(lrm.out.final,data$cabinet.num)

b <- lrm.out.final.rob$coef
se <- sqrt(diag(lrm.out.final.rob$var))
w <- b/se
p <- 1-(abs(pnorm(w)-0.5)*2)
table.1 <- cbind(b,se,w,p)
round(table.1,3)
write.csv(table.1,file="table.1.csv")

## simulation

# function
median.duration <- function(x,b){
risk <- survive <- array()
survive[1] <- 1
for (i in 1:120){
x[2] <- i
xb <- x%*%b
risk[i] <- 1/(1+exp(-xb))
survive[(i+1)] <- survive[i]*(1-risk[i])
}
sum(survive > 0.5)-1
}

# setup
b <- lrm.out.final$coef
x.var <- cbind(minister.num,senator,gov.rate.rep,pass,partisan2,experienceArmy,experienceNavy,as.integer(bukan>0),agriculture)
x.var.mean <- apply(x.var,2,mean)
setx.base <- c(1,0,round(x.var.mean,0))
setx.base
setx.more <- round(c(1,0,(x.var.mean+apply(x.var,2,sd))),0)
setx.more[10] <- 0
setx.more

# do it
setx <- setx.base
median.duration(setx,b)

median.duration.out <- array()
for (j in 3:length(setx.base)){
setx <- setx.base
setx[j] <- setx.more[j]
median.duration.out[j] <- median.duration(setx,b)
}
median.duration.out

write.csv(cbind(setx.base,setx.more,median.duration.out),file="sim.csv")

###################################
# figure 1

b <- lrm.out.final$coef
x <- setx.base
risk <- survive <- array()
survive[1] <- 1
for (i in 1:120){
x[2] <- i
xb <- x%*%b
risk[i] <- 1/(1+exp(-xb))
survive[(i+1)] <- survive[i]*(1-risk[i])
}
survive.plus <- survive

b0 <- b
b0[2] <- 0
risk <- survive <- array()
survive[1] <- 1
for (i in 1:120){
x[2] <- i
xb <- x%*%b0
risk[i] <- 1/(1+exp(-xb))
survive[(i+1)] <- survive[i]*(1-risk[i])
}
survive.zero <- survive

b.minus <- b
b.minus[2] <- -b[2]
risk <- survive <- array()
survive[1] <- 1
for (i in 1:120){
x[2] <- i
xb <- x%*%b.minus
risk[i] <- 1/(1+exp(-xb))
survive[(i+1)] <- survive[i]*(1-risk[i])
}
survive.minus <- survive

jpeg(file="figure.rev.jpeg")
plot(survive.plus,type='l',lwd=4,ylim=c(0,1),xlim=c(1,60),
main=c("}P@ťƑm"),xlab=c(""),ylab=c("m"))
lines(survive.zero)
lines(survive.minus,lty=2)
legend(20,1,lwd=c(1,1,4),lty=c(2,1,1),c("W","W0","W"))
dev.off()


# interaction

lrm.out.interaction.agriculture <- glm(fall ~ duration + minister.num 
 + senator 
 + gov.rate.rep + pass + partisan2
 + experienceArmy + experienceNavy + as.integer(bukan>0) 
 + agriculture + agriculture:calender,
 family=binomial, data=data)
summary(lrm.out.interaction.agriculture)

temporal.agriculture.coef <- lrm.out.interaction.agriculture$coef[11] + (lrm.out.interaction.agriculture$coef[12]*calender) 
plot(temporal.agriculture.coef)
change.point <- sum(temporal.agriculture.coef>0)
data$year[change.point]
data$month[change.point]

lrm.out.interaction.gov.rate.rep <- glm(fall ~ duration + minister.num 
 + senator 
 + gov.rate.rep + pass + partisan2
 + experienceArmy + experienceNavy + as.integer(bukan>0) 
 + agriculture + gov.rate.rep:calender,
 family=binomial, data=data)
summary(lrm.out.interaction.gov.rate.rep)

temporal.gov.rate.rep.coef <- lrm.out.interaction.gov.rate.rep$coef[11] + (lrm.out.interaction.gov.rate.rep$coef[12]*calender) 
plot(temporal.gov.rate.rep.coef)
sum(temporal.gov.rate.rep.coef>0)



###################
# cutpoint analysis

ym <- data$year + ((data$month-1)/12)
data.half <- b <- se <- UB <- LB <- sig <- cutpoint <- list()

cutpoint[[1]] <- cutpoint[[2]] <- c(1:731) #cutpoint <- c(150:650)
b[[1]] <- b[[2]] <- se[[1]] <- se[[2]] <- 
UB[[1]] <- UB[[2]] <- LB[[1]] <- LB[[2]] <- 
sig[[1]] <- sig[[2]] <- 
matrix(NA,length(cutpoint[[1]]),11)
AIC <- matrix(NA,length(cutpoint[[1]]),2)
start.time <- date()
for (i in 1:length(cutpoint[[1]])){
data.half[[1]] <- data[1:cutpoint[[1]][i],]
data.half[[2]] <- data[(cutpoint[[1]][i]+1):732,]
for (j in 1:2){
try(lrm.out <- lrm(fall ~ duration + minister.num 
 + senator 
 + gov.rate.rep + pass + partisan2
 + experienceArmy + experienceNavy + as.integer(bukan>0) 
 + agriculture,
 data=data.half[[j]],y=T,x=T))
try(lrm.out.rob <- robcov(lrm.out,data.half[[j]]$cabinet.num))
try(b[[j]][i,] <- lrm.out.rob$coef)
try(se[[j]][i,] <- sqrt(diag(lrm.out.rob$var)))
try(UB[[j]][i,] <- b[[j]][i,] + (1.96*se[[j]][i,]))
try(LB[[j]][i,] <- b[[j]][i,] - (1.96*se[[j]][i,]))
try(sig[[j]][i,] <- as.integer(UB[[j]][i,]*LB[[j]][i,]>0)*as.integer(sign(b[[j]][i,])==sign(lrm.out.final.rob$coef)))
try(AIC[i,j] <- lrm.out$deviance[2])
}
}
end.time <- date()
start.time
end.time 
# 34 secs

var.num <- c(1:11)
j <- 1
for(v in var.num){
for(t in 1:length(cutpoint[[j]])){
if(is.na(sig[[j]][t,v])==0){
if(sig[[j]][t,v]==1){
plot(ym[cutpoint[[j]][t]],v,xlim=c(1884,1948),ylim=c(1,11))
par(new=T)
}
}
}
}

j <- 2

write.csv(sig[[1]],"sig.former.csv")
write.csv(sig[[2]],"sig.latter.csv")

AIC.sum <- apply(AIC,1,sum)
write.csv(cbind(data$year[cutpoint[[1]]],data$month[cutpoint[[1]]],AIC.sum),"aic.csv")

data$year[320]
data$month[320]

#cbind(data$year,data$month)
